summaryrefslogtreecommitdiffstats
path: root/toolkit
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-05-07 15:25:20 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-05-11 12:17:42 +0000
commit82d68f9cbce4073a727c43b4a8e81d39871b71eb (patch)
tree64b3a9e1092586afee46899adfd00070821613b8 /toolkit
parenttdf#91138 - hold reference until idle dispose. (diff)
downloadcore-82d68f9cbce4073a727c43b4a8e81d39871b71eb.tar.gz
core-82d68f9cbce4073a727c43b4a8e81d39871b71eb.zip
convert COMMAND_ constants to scoped enum
Change-Id: I88e67f89dbbab0646e8f106dfeb32c6ee1bb0b95 Reviewed-on: https://gerrit.libreoffice.org/15671 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'toolkit')
-rw-r--r--toolkit/source/awt/vclxwindow.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/toolkit/source/awt/vclxwindow.cxx b/toolkit/source/awt/vclxwindow.cxx
index ba8e5b3feb11..232ee05041d8 100644
--- a/toolkit/source/awt/vclxwindow.cxx
+++ b/toolkit/source/awt/vclxwindow.cxx
@@ -671,9 +671,9 @@ void VCLXWindow::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
case VCLEVENT_WINDOW_COMMAND:
{
CommandEvent* pCmdEvt = static_cast<CommandEvent*>(rVclWindowEvent.GetData());
- if ( mpImpl->getMouseListeners().getLength() && ( pCmdEvt->GetCommand() == COMMAND_CONTEXTMENU ) )
+ if ( mpImpl->getMouseListeners().getLength() && ( pCmdEvt->GetCommand() == CommandEventId::ContextMenu ) )
{
// COMMAND_CONTEXTMENU als mousePressed mit PopupTrigger = sal_True versenden...
Point aWhere = static_cast< CommandEvent* >( rVclWindowEvent.GetData() )->GetMousePosPixel();
if ( !pCmdEvt->IsMouseEvent() )
{ // for keyboard events, we set the coordinates to -1,-1. This is a slight HACK, but the current API
@@ -671,9 +671,9 @@ void VCLXWindow::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
{
- // COMMAND_CONTEXTMENU als mousePressed mit PopupTrigger = sal_True versenden...
+ // CommandEventId::ContextMenu als mousePressed mit PopupTrigger = sal_True versenden...
Point aWhere = static_cast< CommandEvent* >( rVclWindowEvent.GetData() )->GetMousePosPixel();
if ( !pCmdEvt->IsMouseEvent() )